![NPM](https://nodei.co/npm/gulp-build-html.png?downloads=true)

> Used to process html files to automatically concat css and js files, and meanwhile update html references.

## Usage
This plugin works similarly as gulp-useref but supports inline scripts.

#### Style1
```html
<!-- build:css ../css/index.html.allinone.css -->
<link rel = "stylesheet" href = "../css/view1/a.css"/>
<link rel = "stylesheet" href = "../css/view1/b.css"/>
<!-- endbuild -->
```

```html
<!-- build:js index.html.allinone.js -->
<script type = "text/javascript" src = "../js/view1/a.js"></script>
<script type = "text/javascript" src = "../js/view1/b.js"></script>
<script type = "text/javascript">
    alert("hello, world")
</script>
<script type = "text/javascript" src = "../js/view2/c.js"></script>
<!-- endbuild -->
```

#### Style2
```html
<slot for="merge-reference-content"
      fileType="css"
      outputLocation="file"
      outputFilePath="../css/${fileBaseName}.allinone.css"
	>
    <link rel = "stylesheet" href = "../css/view1/a.css"/>
    <link rel = "stylesheet" href = "../css/view1/b.css"/>
</slot>
```

```html
<slot for="merge-reference-content"
      fileType="js"
      outputLocation="inline"
	>
    <script type = "text/javascript" src = "../js/view1/a.js"></script>
    <script type = "text/javascript" src = "../js/view1/b.js"></script>
    <script type = "text/javascript">
        alert("hello, world")
    </script>
    <script type = "text/javascript" src = "../js/view2/c.js"></script>
</slot>
```

## Note
1. For css build blocks, the css reference style should be like "\<link rel = "stylesheet" href = "[href]"/>", or else the associated file would not be built in.

## Style2 Options
1. `fileType` - Target file type. Currently only `css` and `js` are supported.
2. `outputLocation` - Where the concated file content should output.<br/>Supported enum values are `file`(which requires option `outputFilePath`) and `inline`. Value `inline` will output the concated content inside the html file.<br/>Currently no more actions such as uglify or minimization is supported. You may specify `outputLocation` to `file` and then use plugin `gulp-resolve-import` to import after uglifying or minimizing the content.<br/>Note that when building css, asset references in the source css file will be automatically adjusted to the output location.
3. `outputFilePath` - Which file to create or override to output the concated reference content. Relative (to the html file) path is supported. 

## License

MIT
